@@ -49,3 +49,6 @@
 #undef NCURSES_970530
 
 #undef GETTEXT_PACKAGE
+
+#undef HAVE_CDROMCLOSETRAY_IOCTL
+#undef DEFAULT_MIXER
