@@ -213,6 +213,27 @@ cddb_slave_client_query (CDDBSlaveClient *client,
 	return result;
 }
 
+void
+cddb_slave_client_save (CDDBSlaveClient *client,
+			const char *discid)
+{
+	GNOME_Media_CDDBSlave2 cddb;
+	CORBA_Environment ev;
+
+	g_return_if_fail (IS_CDDB_SLAVE_CLIENT (client));
+	g_return_if_fail (discid != NULL);
+
+	CORBA_exception_init (&ev);
+	cddb = client->priv->objref;
+	GNOME_Media_CDDBSlave2_save (cddb, discid, &ev);
+
+	if (BONOBO_EX (&ev)) {
+		g_warning ("Could not save %s\n%s", discid, CORBA_exception_id (&ev));
+	}
+
+	CORBA_exception_free (&ev);
+}
+			
 /**
  * cddb_slave_client_add_listener:
  * @client: Client of the CDDBSlave to add a listener to.
@@ -501,7 +522,7 @@ cddb_slave_client_set_tracks (CDDBSlaveClient *client,
 
 	g_return_if_fail (IS_CDDB_SLAVE_CLIENT (client));
 
-	for (i = 0; *track_info != NULL; i++) {
+	for (i = 0; track_info[i] != NULL; i++) {
 		; /* Count the number of tracks */
 	}
 	
@@ -585,8 +606,8 @@ cddb_slave_client_get_year (CDDBSlaveClient *client,
 	CORBA_Environment ev;
 	CORBA_short ret;
 	
-	g_return_val_if_fail (IS_CDDB_SLAVE_CLIENT (client), NULL);
-	g_return_val_if_fail (discid != NULL, NULL);
+	g_return_val_if_fail (IS_CDDB_SLAVE_CLIENT (client), -1);
+	g_return_val_if_fail (discid != NULL, -1);
 	
 	objref = client->priv->objref;
 	
@@ -597,7 +618,7 @@ cddb_slave_client_get_year (CDDBSlaveClient *client,
 		g_warning ("Error getting year\n%s",
 			   CORBA_exception_id (&ev));
 		CORBA_exception_free (&ev);
-		return NULL;
+		return -1;
 	}
 
 	CORBA_exception_free (&ev);
