@@ -69,6 +69,8 @@ typedef struct _TrackEditorDialog {
 	GtkTextBuffer *buffer;
 	GtkTreeModel *model;
 
+	int current_track; /* The array offset that is currently
+			      selected in the tree */
 	CDDBInfo *info;
 } TrackEditorDialog;
 
@@ -226,6 +228,11 @@ static char *genres[] = {
 	NULL
 };
 
+#define MODEL_TRACK_NO 0
+#define MODEL_NAME 1
+#define MODEL_LENGTH 2
+#define MODEL_EDITABLE 3
+
 static GtkTreeModel *
 make_tree_model (void)
 {
@@ -263,9 +270,11 @@ build_track_list (TrackEditorDialog *td)
 
 		length = secs_to_string (td->info->track_info[i]->length);
 		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter, 0, i + 1,
-				    1, td->info->track_info[i]->name,
-				    2, length, -1);
+		gtk_list_store_set (store, &iter,
+				    MODEL_TRACK_NO, i + 1,
+				    MODEL_NAME, td->info->track_info[i]->name,
+				    MODEL_LENGTH, length,
+				    MODEL_EDITABLE, TRUE, -1);
 		g_free (length);
 	}
 }
@@ -305,11 +314,31 @@ make_genre_list (void)
 		genre_list = g_list_prepend (genre_list, genres[i]);
 	}
 
-	genre_list = g_list_sort (genre_list, strcmp);
+	genre_list = g_list_sort (genre_list, (GCompareFunc) strcmp);
 	
 	return genre_list;
 }
 
+static void
+extra_info_changed (GtkTextBuffer *tb,
+		    TrackEditorDialog *td)
+{
+	GtkTextIter start, end;
+	char *text;
+
+	if (td->current_track == -1) {
+		return; /* Hmmm, curious */
+	}
+
+	if (td->info->track_info[td->current_track]->comment != NULL) {
+		g_free (td->info->track_info[td->current_track]->comment);
+	}
+	
+	gtk_text_buffer_get_bounds (tb, &start, &end);
+	text = gtk_text_buffer_get_text (tb, &start, &end, FALSE);
+	td->info->track_info[td->current_track]->comment = text;
+}
+	
 static void
 track_selection_changed (GtkTreeSelection *selection,
 			 TrackEditorDialog *td)
@@ -324,11 +353,26 @@ track_selection_changed (GtkTreeSelection *selection,
 		gtk_tree_model_get (model, &iter, 0, &track, -1);
 		comment = td->info->track_info[track - 1]->comment;
 
+		td->current_track = track - 1;
+		g_signal_handlers_block_matched (G_OBJECT (td->buffer),
+						 G_SIGNAL_MATCH_FUNC,
+						 0, 0, NULL,
+						 G_CALLBACK (extra_info_changed),
+						 td);
 		if (comment != NULL) {
 			gtk_text_buffer_set_text (td->buffer, comment, -1);
 		} else {
 			gtk_text_buffer_set_text (td->buffer, "", -1);
 		}
+		g_signal_handlers_unblock_matched (G_OBJECT (td->buffer),
+						   G_SIGNAL_MATCH_FUNC,
+						   0, 0, NULL,
+						   G_CALLBACK (extra_info_changed),
+						   td);
+		gtk_widget_set_sensitive (td->extra_info, TRUE);
+	} else {
+		/* No track selected, you can enter a comment */
+		gtk_widget_set_sensitive (td->extra_info, FALSE);
 	}
 }
 
@@ -414,7 +458,7 @@ static void
 comment_changed (GtkEntry *entry,
 		 TrackEditorDialog *td)
 {
-	char *comment;
+	const char *comment;
 
 	if (td->info == NULL) {
 		return;
@@ -430,6 +474,30 @@ comment_changed (GtkEntry *entry,
 	td->dirty = TRUE;
 }
 
+static void
+track_name_edited (GtkCellRendererText *cell,
+		   char *path_string,
+		   char *new_text,
+		   TrackEditorDialog *td)
+{
+	GtkTreeModel *model = td->model;
+	GtkTreeIter iter;
+	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
+	int track_no;
+
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter, 0, &track_no, -1);
+
+	g_print ("track no %d\n", track_no);
+	if (td->info->track_info[track_no - 1]->name != NULL) {
+		g_free (td->info->track_info[track_no - 1]->name);
+	}
+	td->info->track_info[track_no - 1]->name = g_strdup (new_text);
+
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 1, new_text, -1);
+	gtk_tree_path_free (path);
+}
+
 static void
 load_new_track_data (TrackEditorDialog *td,
 		     const char *discid)
@@ -537,6 +605,7 @@ make_track_editor_control (void)
 	td = g_new0 (TrackEditorDialog, 1);
 
 	td->info = NULL;
+	td->current_track = -1;
 	td->dirty = FALSE;
 	
 	td->parent = gtk_vbox_new (FALSE, 4);
@@ -650,22 +719,27 @@ make_track_editor_control (void)
 	td->tracks = gtk_tree_view_new_with_model (td->model);
 	g_object_unref (td->model);
 
-	selection = gtk_tree_view_get_selection (td->tracks);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (td->tracks));
 	g_signal_connect (G_OBJECT (selection), "changed",
 			  G_CALLBACK (track_selection_changed), td);
 	
 	cell = gtk_cell_renderer_text_new ();
-	col = gtk_tree_view_column_new_with_attributes (" ", cell, "text", 0, NULL);
+	col = gtk_tree_view_column_new_with_attributes (" ", cell,
+							"text", MODEL_TRACK_NO, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (td->tracks), col);
-	
+
+	cell = gtk_cell_renderer_text_new ();
+	g_signal_connect (G_OBJECT (cell), "edited",
+			  G_CALLBACK (track_name_edited), td);
 	col = gtk_tree_view_column_new_with_attributes (_("Title"), cell,
-							"text", 1,
-							"editable", 3,
+							"text", MODEL_NAME,
+							"editable", MODEL_EDITABLE,
 							NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (td->tracks), col);
 
+	cell = gtk_cell_renderer_text_new ();
 	col = gtk_tree_view_column_new_with_attributes (_("Length"), cell,
-							"text", 2, NULL);
+							"text", MODEL_LENGTH, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (td->tracks), col);
 
 	gtk_container_add (GTK_CONTAINER (sw), td->tracks);
@@ -693,6 +767,9 @@ make_track_editor_control (void)
 
 	td->extra_info = gtk_text_view_new ();
 	td->buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (td->extra_info));
+	g_signal_connect (G_OBJECT (td->buffer), "changed",
+			  G_CALLBACK (extra_info_changed), td);
+	gtk_widget_set_sensitive (td->extra_info, FALSE);
 	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (td->extra_info),
 				     GTK_WRAP_WORD);
 	gtk_box_pack_start (GTK_BOX (ad_vbox2), td->extra_info, TRUE, TRUE, 0);
@@ -731,11 +808,45 @@ cddb_track_editor_from_servant (PortableServer_Servant servant)
 	return (CDDBTrackEditor *) bonobo_object_from_servant (servant);
 }
 
+static void
+sync_cddb_info (CDDBInfo *info)
+{
+	g_return_if_fail (info != NULL);
+
+	cddb_slave_client_set_disc_title (client, info->discid, info->title);
+	cddb_slave_client_set_artist (client, info->discid, info->artist);
+
+	/* Only set the comment if there is one */
+	if (info->comment != NULL && *(info->comment) != 0) {
+		cddb_slave_client_set_comment (client, info->discid, info->comment);
+	}
+
+	if (info->genre != NULL && *(info->genre) != 0) {
+		cddb_slave_client_set_genre (client, info->discid, info->genre);
+	}
+
+	if (info->year != -1) {
+		cddb_slave_client_set_year (client, info->discid, info->year);
+	}
+
+	cddb_slave_client_set_tracks (client, info->discid, info->track_info);
+}
+
 static void
 dialog_response (GtkDialog *dialog,
 		 int response_id,
 		 CDDBTrackEditor *editor)
 {
+	switch (response_id) {
+	case 1:
+		g_print ("Saving...\n");
+		sync_cddb_info (editor->td->info);
+		cddb_slave_client_save (client, editor->discid);
+		break;
+
+	default:
+		break;
+	}
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 	editor->dialog = NULL;
 }
