@@ -63,7 +63,7 @@ cdrom_eject (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__, 
+				      G_GNUC_FUNCTION, 
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -78,7 +78,7 @@ cdrom_next (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -94,7 +94,7 @@ cdrom_ffwd (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -113,7 +113,7 @@ cdrom_play (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -128,7 +128,7 @@ cdrom_pause (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -143,7 +143,7 @@ cdrom_stop (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__, 
+				      G_GNUC_FUNCTION, 
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -158,7 +158,7 @@ cdrom_rewind (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -173,7 +173,7 @@ cdrom_back (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -189,7 +189,7 @@ cdrom_get_status (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -205,7 +205,7 @@ cdrom_close_tray (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -221,7 +221,39 @@ cdrom_get_cddb_data (GnomeCDRom *cdrom,
 		*error = g_error_new (GNOME_CDROM_ERROR,
 				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
 				      "%s has not been implemented in %s",
-				      __FUNCTION__,
+				      G_GNUC_FUNCTION,
+				      G_OBJECT_TYPE_NAME (cdrom));
+	}
+
+	return FALSE;
+}
+
+static gboolean
+cdrom_set_volume (GnomeCDRom *cdrom,
+		  int volume,
+		  GError **error)
+{
+	if (error) {
+		*error = g_error_new (GNOME_CDROM_ERROR,
+				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
+				      "%s has not been implemented in %s",
+				      G_GNUC_FUNCTION,
+				      G_OBJECT_TYPE_NAME (cdrom));
+	}
+
+	return FALSE;
+}
+
+static gboolean
+cdrom_is_cdrom_device (GnomeCDRom *cdrom,
+		       const char *device,
+		       GError **error)
+{
+	if (error) {
+		*error = g_error_new (GNOME_CDROM_ERROR,
+				      GNOME_CDROM_ERROR_NOT_IMPLEMENTED,
+				      "%s has not been implemented in %s",
+				      G_GNUC_FUNCTION,
 				      G_OBJECT_TYPE_NAME (cdrom));
 	}
 
@@ -246,7 +278,9 @@ class_init (GnomeCDRomClass *klass)
 	klass->back = cdrom_back;
 	klass->get_status = cdrom_get_status;
 	klass->close_tray = cdrom_close_tray;
-
+	klass->set_volume = cdrom_set_volume;
+	klass->is_cdrom_device = cdrom_is_cdrom_device;
+	
 	/* CDDB stuff */
 	klass->get_cddb_data = cdrom_get_cddb_data;
 
@@ -464,7 +498,6 @@ gnome_cdrom_status_equal (GnomeCDRomStatus *status1,
 	return FALSE;
 }
 
-
 GnomeCDRomStatus *
 gnome_cdrom_copy_status (GnomeCDRomStatus *original)
 {
@@ -480,3 +513,36 @@ gnome_cdrom_copy_status (GnomeCDRomStatus *original)
 
 	return status;
 }
+
+gboolean
+gnome_cdrom_set_device (GnomeCDRom *cdrom,
+			const char *device,
+			GError **error)
+{
+	GnomeCDRomClass *klass;
+	
+	klass = GNOME_CDROM_GET_CLASS (cdrom);
+	return klass->set_device (cdrom, device, error);
+}
+
+gboolean
+gnome_cdrom_set_volume (GnomeCDRom *cdrom,
+			int volume,
+			GError **error)
+{
+	GnomeCDRomClass *klass;
+
+	klass = GNOME_CDROM_GET_CLASS (cdrom);
+	return klass->set_volume (cdrom, volume, error);
+}
+
+gboolean
+gnome_cdrom_is_cdrom_device (GnomeCDRom *cdrom,
+			     const char *device,
+			     GError **error)
+{
+	GnomeCDRomClass *klass;
+
+	klass = GNOME_CDROM_GET_CLASS (cdrom);
+	return klass->is_cdrom_device (cdrom, device, error);
+}
