@@ -337,6 +337,13 @@ freebsd_cdrom_next (GnomeCDRom *cdrom,
 		return FALSE;
 	}
 
+	if (status->cd != GNOME_CDROM_STATUS_OK) {
+		freebsd_cdrom_close (lcd);
+		g_free (status);
+		
+		return TRUE;
+	}
+
 	track = status->track + 1;
 	g_free (status);
 	if (track > lcd->priv->number_tracks) {
@@ -696,6 +703,13 @@ freebsd_cdrom_rewind (GnomeCDRom *cdrom,
 		return FALSE;
 	}
 
+	if (status->cd != GNOME_CDROM_STATUS_OK) {
+		freebsd_cdrom_close (lcd);
+		g_free (status);
+
+		return TRUE;
+	}
+
 	msf = &status->absolute;
 
 	frames = msf_to_frames (msf);
@@ -755,6 +769,13 @@ freebsd_cdrom_back (GnomeCDRom *cdrom,
 		return FALSE;
 	}
 
+	if (status->cd != GNOME_CDROM_STATUS_OK) {
+		freebsd_cdrom_close (lcd);
+		g_free (status);
+
+		return TRUE;
+	}
+
 	/* If we're > 0:00 on the track go back to the start of it, 
 	   otherwise go to the previous track */
 	if (status->relative.minute != 0 || status->relative.second != 0) {
@@ -962,6 +983,72 @@ freebsd_cdrom_close_tray (GnomeCDRom *cdrom,
 	return TRUE;
 }
 
+static gboolean
+freebsd_cdrom_set_volume (GnomeCDRom *cdrom,
+			int volume,
+			GError **error)
+{
+	FreeBSDCDRom *lcd;
+	FreeBSDCDRomPrivate *priv;
+	struct ioc_vol vol;
+
+	lcd = FREEBSD_CDROM (cdrom);
+	priv = lcd->priv;
+
+	if (freebsd_cdrom_open (lcd, error) == FALSE) {
+		return FALSE;
+	}
+	
+	vol.vol[0] = (u_char)volume;
+	vol.vol[1] = vol.vol[2] = vol.vol[3] = vol.vol[0];
+	
+	if (ioctl (priv->cdrom_fd, CDIOCSETVOL, &vol) < 0) {
+		if (error) {
+			*error = g_error_new (GNOME_CDROM_ERROR,
+					      GNOME_CDROM_ERROR_SYSTEM_ERROR,
+					      "(freebsd_cdrom_set_volume:1): ioctl failed %s",
+					      strerror (errno));
+		}
+
+		freebsd_cdrom_close (lcd);
+		return FALSE;
+	}
+
+	freebsd_cdrom_close (lcd);
+	return TRUE;
+}
+
+static gboolean
+freebsd_cdrom_is_cdrom_device (GnomeCDRom *cdrom,
+			       const char *device,
+			       GError **error)
+{
+	int fd;
+
+	if (device == NULL || *device == 0) {
+		return FALSE;
+	}
+	
+	fd = open (device, O_RDONLY | O_NONBLOCK);
+	if (fd < 0) {
+		return FALSE;
+	}
+
+	/* Fire a harmless ioctl at the device. */
+	if (ioctl (fd, CDIOCSTOP, 0) < 0) {
+		/* Failed, it's not a CDROM drive */
+		g_print ("%s is not a CDROM drive", device);
+		close (fd);
+		
+		return FALSE;
+	}
+	
+	g_print ("%s is a CDROM drive", device);
+	close (fd);
+
+	return TRUE;
+}
+
 static gboolean
 freebsd_cdrom_get_cddb_data (GnomeCDRom *cdrom,
 			   GnomeCDRomCDDBData **data,
@@ -1036,6 +1123,19 @@ freebsd_cdrom_set_device (GnomeCDRom *cdrom,
 		g_free (priv->cdrom_device);
 	}
 	priv->cdrom_device = g_strdup (device);
+	
+	if (gnome_cdrom_is_cdrom_device (GNOME_CDROM (lcd),
+					 priv->cdrom_device, error) == FALSE) {
+		if (error) {
+			*error = g_error_new (GNOME_CDROM_ERROR,
+					      GNOME_CDROM_ERROR_NOT_OPENED,
+					      "%s does not point to a valid CDRom device. This may be caused by:\n"
+					      "a) CD support is not compiled into Linux\n"
+					      "b) You do not have the correct permissions to access the CD drive\n"
+					      "c) %s is not the CD drive.\n",					     
+					      priv->cdrom_device, priv->cdrom_device);
+		}
+	}
 
 	/* Force the new CD to be scanned at next update cycle */
 	g_free (priv->recent_status);
@@ -1065,7 +1165,9 @@ class_init (FreeBSDCDRomClass *klass)
 	cdrom_class->back = freebsd_cdrom_back;
 	cdrom_class->get_status = freebsd_cdrom_get_status;
 	cdrom_class->close_tray = freebsd_cdrom_close_tray;
-
+	cdrom_class->set_volume = freebsd_cdrom_set_volume;
+	cdrom_class->is_cdrom_device = freebsd_cdrom_is_cdrom_device;
+	
 	/* For CDDB */
   	cdrom_class->get_cddb_data = freebsd_cdrom_get_cddb_data;
 
@@ -1175,9 +1277,21 @@ gnome_cdrom_new (const char *cdrom_device,
 	priv->cdrom_device = g_strdup (cdrom_device);
 	priv->update = update;
 
-	if (freebsd_cdrom_open (cdrom, error) == FALSE) {
-	}
+	freebsd_cdrom_open (cdrom, error);
 	freebsd_cdrom_close (cdrom);
+	if (gnome_cdrom_is_cdrom_device (GNOME_CDROM (cdrom),
+					 cdrom->priv->cdrom_device,
+					 error) == FALSE) {
+		if (error) {
+			*error = g_error_new (GNOME_CDROM_ERROR,
+					      GNOME_CDROM_ERROR_NOT_OPENED,
+					      "%s does not point to a valid CDRom device. This may be caused by:\n"
+					      "a) CD support is not compiled into Linux\n"
+					      "b) You do not have the correct permissions to access the CD drive\n"
+					      "c) %s is not the CD drive.\n",					     
+					      cdrom->priv->cdrom_device, cdrom->priv->cdrom_device);
+		}
+	}
 	
 	/* Force an update so that a status will always exist */
 	update_cd (cdrom);
