@@ -10,6 +10,7 @@
 #include <config.h>
 #endif
 
+#include <libgnome/gnome-i18n.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
@@ -140,16 +141,17 @@ linux_cdrom_open (LinuxCDRom *lcd,
 		if (error) {
 			*error = g_error_new (GNOME_CDROM_ERROR,
 					      GNOME_CDROM_ERROR_NOT_OPENED,
-					      "Unable to open %s. This may be caused by:\n"
+					      _("Unable to open %s. This may be caused by:\n"
 					      "a) CD support is not compiled into Linux\n"
 					      "b) You do not have the correct permissions to access the CD drive\n"
-					      "c) %s is not the CD drive.\n",					     
+					      "c) %s is not the CD drive.\n"),					     
 					      lcd->priv->cdrom_device, lcd->priv->cdrom_device);
 		}
 
 		return FALSE;
 	}
 
+	
 	lcd->priv->ref_count = 1;
 	return TRUE;
 }
@@ -214,12 +216,12 @@ linux_cdrom_update_cd (LinuxCDRom *lcd)
 	priv = lcd->priv;
 
 	if (linux_cdrom_open (lcd, &error) == FALSE) {
-		g_warning ("Error opening CD");
+		g_warning (_("Error opening CD"));
 		return;
 	}
 
 	if (ioctl (priv->cdrom_fd, CDROMREADTOCHDR, priv->tochdr) < 0) {
-		g_warning ("Error reading CD header");
+		g_warning (_("Error reading CD header"));
 		linux_cdrom_close (lcd);
 
 		return;
@@ -236,7 +238,7 @@ linux_cdrom_update_cd (LinuxCDRom *lcd)
 		tocentry.cdte_format = CDROM_MSF;
 
 		if (ioctl (priv->cdrom_fd, CDROMREADTOCENTRY, &tocentry) < 0) {
-			g_warning ("IOCtl failed");
+			g_warning (_("IOCtl failed"));
 			continue;
 		}
 
@@ -248,7 +250,7 @@ linux_cdrom_update_cd (LinuxCDRom *lcd)
 	tocentry.cdte_track = CDROM_LEADOUT;
 	tocentry.cdte_format = CDROM_MSF;
 	if (ioctl (priv->cdrom_fd, CDROMREADTOCENTRY, &tocentry) < 0) {
-		g_warning ("Error getting leadout");
+		g_warning (_("Error getting leadout"));
 		linux_cdrom_invalidate (lcd);
 		return;
 	}
@@ -256,8 +258,8 @@ linux_cdrom_update_cd (LinuxCDRom *lcd)
 	calculate_track_lengths (lcd);
 
 #ifdef DEBUG
-	g_print ("CD changed\n"
-		 "Track count: %d\n------------------\n",
+	g_print (_("CD changed\n"
+		 "Track count: %d\n------------------\n"),
 		 priv->number_tracks);
 #endif
 	
@@ -288,7 +290,7 @@ linux_cdrom_eject (GnomeCDRom *cdrom,
 			if (error) {
 				*error = g_error_new (GNOME_CDROM_ERROR,
 						      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-						      "(eject): ioctl failed: %s",
+						      _("(eject): ioctl failed: %s"),
 						      strerror (errno));
 			}
 
@@ -472,7 +474,7 @@ linux_cdrom_play (GnomeCDRom *cdrom,
 			if (error) {
 				*error = g_error_new (GNOME_CDROM_ERROR,
 						      GNOME_CDROM_ERROR_NOT_READY,
-						      "(linux_cdrom_play): Drive not ready");
+						      _("(linux_cdrom_play): Drive not ready"));
 			}
 
 			linux_cdrom_close (lcd);
@@ -492,7 +494,7 @@ linux_cdrom_play (GnomeCDRom *cdrom,
 		if (error) {
 			*error = g_error_new (GNOME_CDROM_ERROR,
 					      GNOME_CDROM_ERROR_NOT_READY,
-					      "(linux_cdrom_play): Drive still not ready");
+					      _("(linux_cdrom_play): Drive still not ready"));
 		}
 
 		linux_cdrom_close (lcd);
@@ -557,7 +559,7 @@ linux_cdrom_play (GnomeCDRom *cdrom,
 			if (error) {
 				*error = g_error_new (GNOME_CDROM_ERROR,
 						      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-						      "(linux_cdrom_play) ioctl failed %s",
+						      _("(linux_cdrom_play) ioctl failed %s"),
 						      strerror (errno));
 			}
 
@@ -593,7 +595,7 @@ linux_cdrom_pause (GnomeCDRom *cdrom,
 		if (error) {
 			*error = g_error_new (GNOME_CDROM_ERROR,
 					      GNOME_CDROM_ERROR_NOT_READY,
-					      "(linux_cdrom_pause): Drive not ready");
+					      _("(linux_cdrom_pause): Drive not ready"));
 		}
 
 		g_free (status);
@@ -606,7 +608,7 @@ linux_cdrom_pause (GnomeCDRom *cdrom,
 			if (error) {
 				*error = g_error_new (GNOME_CDROM_ERROR,
 						      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-						      "(linux_cdrom_pause): Resume failed %s",
+						      _("(linux_cdrom_pause): Resume failed %s"),
 						      strerror (errno));
 			}
 
@@ -625,7 +627,7 @@ linux_cdrom_pause (GnomeCDRom *cdrom,
 			if (error) {
 				*error = g_error_new (GNOME_CDROM_ERROR,
 						      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-						      "(linux_cdrom_pause): ioctl failed %s",
+						      _("(linux_cdrom_pause): ioctl failed %s"),
 						      strerror (errno));
 			}
 
@@ -671,7 +673,7 @@ linux_cdrom_stop (GnomeCDRom *cdrom,
 		if (error) {
 			*error = g_error_new (GNOME_CDROM_ERROR,
 					      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-					      "(linux_cdrom_stop) ioctl failed %s",
+					      _("(linux_cdrom_stop) ioctl failed %s"),
 					      strerror (errno));
 		}
 
@@ -826,8 +828,9 @@ linux_cdrom_get_status (GnomeCDRom *cdrom,
 	LinuxCDRomPrivate *priv;
 	GnomeCDRomStatus *realstatus;
 	struct cdrom_subchnl subchnl;
+	struct cdrom_volctrl vol;
 	int cd_status;
-
+	
 	g_return_val_if_fail (status != NULL, TRUE);
 	
 	lcd = LINUX_CDROM (cdrom);
@@ -835,7 +838,8 @@ linux_cdrom_get_status (GnomeCDRom *cdrom,
 
 	*status = g_new (GnomeCDRomStatus, 1);
 	realstatus = *status;
-
+	realstatus->volume = 0;
+	
 	if (linux_cdrom_open (lcd, error) == FALSE) {
 		g_free (realstatus);
 		linux_cdrom_close (lcd);
@@ -885,7 +889,7 @@ linux_cdrom_get_status (GnomeCDRom *cdrom,
 		if (error) {
 			*error = g_error_new (GNOME_CDROM_ERROR,
 					      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-					      "(linux_cdrom_get_status): ioctl error %s",
+					      _("(linux_cdrom_get_status): ioctl error %s"),
 					      strerror (errno));
 		}
 
@@ -899,7 +903,7 @@ linux_cdrom_get_status (GnomeCDRom *cdrom,
 		if (error) {
 			*error = g_error_new (GNOME_CDROM_ERROR,
 					      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-					      "(linux_cdrom_get_status): CDROMSUBCHNL ioctl failed %s",
+					      _("(linux_cdrom_get_status): CDROMSUBCHNL ioctl failed %s"),
 					      strerror (errno));
 		}
 
@@ -908,6 +912,21 @@ linux_cdrom_get_status (GnomeCDRom *cdrom,
 		return FALSE;
 	}
 
+	/* Get the volume */
+	if (ioctl (priv->cdrom_fd, CDROMVOLREAD, &vol) < 0) {
+		if (error) {
+			*error = g_error_new (GNOME_CDROM_ERROR,
+					      GNOME_CDROM_ERROR_SYSTEM_ERROR,
+					      _("(linux_cdrom_get_status): CDROMVOLREAD ioctl failed %s"),
+					      strerror (errno));
+		}
+
+		linux_cdrom_close (lcd);
+		g_free (realstatus);
+		return FALSE;
+	}
+	realstatus->volume = vol.channel0;
+
 	linux_cdrom_close (lcd);
 
 	ASSIGN_MSF (realstatus->relative, blank_msf);
@@ -966,7 +985,7 @@ linux_cdrom_close_tray (GnomeCDRom *cdrom,
 		if (error) {
 			*error = g_error_new (GNOME_CDROM_ERROR,
 					      GNOME_CDROM_ERROR_SYSTEM_ERROR,
-					      "(linux_cdrom_close_tray): ioctl failed %s",
+					      _("(linux_cdrom_close_tray): ioctl failed %s"),
 					      strerror (errno));
 		}
 
@@ -978,6 +997,72 @@ linux_cdrom_close_tray (GnomeCDRom *cdrom,
 	return TRUE;
 }
 
+static gboolean
+linux_cdrom_set_volume (GnomeCDRom *cdrom,
+			int volume,
+			GError **error)
+{
+	LinuxCDRom *lcd;
+	LinuxCDRomPrivate *priv;
+	struct cdrom_volctrl vol;
+
+	lcd = LINUX_CDROM (cdrom);
+	priv = lcd->priv;
+
+	if (linux_cdrom_open (lcd, error) == FALSE) {
+		return FALSE;
+	}
+	
+	vol.channel0 = volume;
+	vol.channel1 = vol.channel2 = vol.channel3 = volume;
+	
+	if (ioctl (priv->cdrom_fd, CDROMVOLCTRL, &vol) < 0) {
+		if (error) {
+			*error = g_error_new (GNOME_CDROM_ERROR,
+					      GNOME_CDROM_ERROR_SYSTEM_ERROR,
+					      _("(linux_cdrom_set_volume:1): ioctl failed %s"),
+					      strerror (errno));
+		}
+
+		linux_cdrom_close (lcd);
+		return FALSE;
+	}
+
+	linux_cdrom_close (lcd);
+	return TRUE;
+}
+
+static gboolean
+linux_cdrom_is_cdrom_device (GnomeCDRom *cdrom,
+			     const char *device,
+			     GError **error)
+{
+	int fd;
+
+	if (device == NULL || *device == 0) {
+		return FALSE;
+	}
+	
+	fd = open (device, O_RDONLY | O_NONBLOCK);
+	if (fd < 0) {
+		return FALSE;
+	}
+
+	/* Fire a harmless ioctl at the device. */
+	if (ioctl (fd, CDROMSTOP, 0) < 0) {
+		/* Failed, it's not a CDROM drive */
+		g_print (_("%s is not a CDROM drive\n"), device);
+		close (fd);
+		
+		return FALSE;
+	}
+	
+	g_print (_("%s is a CDROM drive\n"), device);
+	close (fd);
+
+	return TRUE;
+}
+
 static gboolean
 linux_cdrom_get_cddb_data (GnomeCDRom *cdrom,
 			   GnomeCDRomCDDBData **data,
@@ -1052,6 +1137,19 @@ linux_cdrom_set_device (GnomeCDRom *cdrom,
 		g_free (priv->cdrom_device);
 	}
 	priv->cdrom_device = g_strdup (device);
+	
+	if (gnome_cdrom_is_cdrom_device (GNOME_CDROM (lcd),
+					 lcd->priv->cdrom_device, error) == FALSE) {
+		if (error) {
+			*error = g_error_new (GNOME_CDROM_ERROR,
+					      GNOME_CDROM_ERROR_NOT_OPENED,
+					      _("%s does not point to a valid CDRom device. This may be caused by:\n"
+					      "a) CD support is not compiled into Linux\n"
+					      "b) You do not have the correct permissions to access the CD drive\n"
+					      "c) %s is not the CD drive.\n"),					     
+					      lcd->priv->cdrom_device, lcd->priv->cdrom_device);
+		}
+	}
 
 	/* Force the new CD to be scanned at next update cycle */
 	g_free (priv->recent_status);
@@ -1081,7 +1179,9 @@ class_init (LinuxCDRomClass *klass)
 	cdrom_class->back = linux_cdrom_back;
 	cdrom_class->get_status = linux_cdrom_get_status;
 	cdrom_class->close_tray = linux_cdrom_close_tray;
-
+	cdrom_class->set_volume = linux_cdrom_set_volume;
+	cdrom_class->is_cdrom_device = linux_cdrom_is_cdrom_device;
+	
 	/* For CDDB */
   	cdrom_class->get_cddb_data = linux_cdrom_get_cddb_data;
 
@@ -1191,9 +1291,21 @@ gnome_cdrom_new (const char *cdrom_device,
 	priv->cdrom_device = g_strdup (cdrom_device);
 	priv->update = update;
 
-	if (linux_cdrom_open (cdrom, error) == FALSE) {
-	}
+	linux_cdrom_open (cdrom, error);
 	linux_cdrom_close (cdrom);
+	if (gnome_cdrom_is_cdrom_device (GNOME_CDROM (cdrom),
+					 cdrom->priv->cdrom_device,
+					 error) == FALSE) {
+		if (error) {
+			*error = g_error_new (GNOME_CDROM_ERROR,
+					      GNOME_CDROM_ERROR_NOT_OPENED,
+					      _("%s does not point to a valid CDRom device. This may be caused by:\n"
+					      "a) CD support is not compiled into Linux\n"
+					      "b) You do not have the correct permissions to access the CD drive\n"
+					      "c) %s is not the CD drive.\n"),					     
+					      cdrom->priv->cdrom_device, cdrom->priv->cdrom_device);
+		}
+	}
 	
 	/* Force an update so that a status will always exist */
 	update_cd (cdrom);
