@@ -64,19 +64,95 @@ gint repeat_counter = 0;
 gchar* active_file = NULL;
 gboolean default_file = FALSE;
 gboolean file_changed = FALSE;
+gboolean show_message = FALSE;
 
 static guint play_id;
 static guint record_id;
 
+extern gboolean able_to_record;
+
+static void
+on_dontshowagain_dialog_destroy_activate (GtkWidget* widget,
+					  gpointer checkbutton)
+{
+	GConfClient *client;
+	gboolean stat = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton));
+	
+	client = gconf_client_get_default ();
+	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/show-warning-messages", !stat, NULL);
+	g_object_unref (client);
+}
+
+gboolean
+check_for_sox (void)
+{
+	char *p;
+	gboolean show_warningmess;
+	GConfClient *client;
+	
+	if (sox_command == NULL) {
+		return FALSE;
+	}
+
+	client = gconf_client_get_default ();
+	show_warningmess = gconf_client_get_bool (client,
+						  "/apps/gnome-sound-recorder/show-warning-messages", NULL);
+	g_object_unref (client);
+
+	p = g_find_program_in_path (sox_command);
+	if (p == NULL) {
+		able_to_record = FALSE;
+		gtk_widget_set_sensitive (GTK_WIDGET (grecord_widgets.Record_button), FALSE);
+		if (show_warningmess) {
+			GtkWidget* dont_show_again_checkbutton = gtk_check_button_new_with_label (_("Don't show this message again."));
+			
+			gchar* show_mess = g_strdup_printf (_("Could not find '%s'.\nSet the correct path to sox in"
+							      "preferences under the tab 'paths'.\n\nIf you don't have"
+							      " sox, you will not be able to record or do any effects."),
+							    sox_command);
+			GtkWidget* mess = gtk_message_dialog_new (NULL,
+								  GTK_DIALOG_MODAL,	
+								  GTK_MESSAGE_WARNING,
+								  GTK_BUTTONS_OK,
+								  show_mess);
+			g_free (show_mess);
+			
+			gtk_widget_show (dont_show_again_checkbutton);
+			gtk_container_add (GTK_CONTAINER (GTK_DIALOG (mess)->vbox), dont_show_again_checkbutton);
+			
+			/* Connect a signal on ok-button, so we can get the stat on the checkbutton */
+			g_signal_connect (mess, "destroy",
+					  G_CALLBACK (on_dontshowagain_dialog_destroy_activate), dont_show_again_checkbutton);
+			
+			gtk_dialog_run (GTK_DIALOG (mess));
+			gtk_widget_destroy (mess);
+		}
+
+		able_to_record = FALSE;
+		gtk_widget_set_sensitive (grecord_widgets.Record_button, FALSE);
+		return FALSE;
+	} else {
+		g_free (p);
+	}
+
+	return TRUE;
+}
+
 /* ------------------- Callbacks ------------------------------- */
 void
 on_record_activate_cb (GtkWidget* widget, gpointer data)
 {
+	show_message = TRUE;
 	/* Check if the sounddevice is ready */
 	if (!check_if_sounddevice_ready ())
 		return;
 
+	if (check_for_sox () == FALSE) {
+		return;
+	}
+	
 	grecord_set_sensitive_progress ();
+	save_set_sensitive (TRUE);
 	file_changed = TRUE;
 
 	/* Reset record-time and stuff */
@@ -242,14 +318,16 @@ on_new_activate_cb (GtkWidget* widget, gpointer data)
 	g_free (file2);
 	g_free (file3);
 
+	
 	default_file = TRUE;
-
+	
 	if (active_file != NULL) {
 		g_free (active_file);
 	}
 	active_file = g_build_filename (temp_dir, temp_filename_play, NULL);
 	file_changed = FALSE;
-
+	save_set_sensitive (FALSE);
+	
 	set_min_sec_time (get_play_time (active_file));
 
 	grecord_set_sensitive_nofile ();
@@ -356,7 +434,7 @@ on_exit_activate_cb (GtkWidget* widget, gpointer data)
 		on_stop_activate_cb (widget, data);
 
 	if (file_changed) {
-		choice = save_dont_or_cancel (_("Don't quit"));
+		choice = save_dont_or_cancel (_("Cancel"));
 		if (choice == SAVE) {
 			save_dialog ();
 			return;
@@ -437,9 +515,9 @@ on_runmixer_activate_cb (GtkWidget* widget, gpointer data)
 	gboolean ret;
 
 	/* Open the mixer */
-	mixer_path = g_find_program_in_path ("gnome-volume-control");
+	mixer_path = g_find_program_in_path (DEFAULT_MIXER);
 	if (mixer_path == NULL) {
-		g_warning (_("Gnome Volume Control is not installed in the path"));
+		g_warning (_("%s is not installed in the path"), DEFAULT_MIXER);
 		return;
 	}
 	
@@ -471,6 +549,7 @@ on_add_echo_activate_cb (GtkWidget* widget, gpointer data)
 	    return;
 
 	file_changed = TRUE;
+	save_set_sensitive (TRUE);
 	add_echo (active_file, TRUE);
 }
 
@@ -622,7 +701,7 @@ store_filename (GtkFileSelection* selector, gpointer file_selector)
 			mess = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						       GTK_MESSAGE_ERROR,
 						       GTK_BUTTONS_OK,
-						       _("'%s is a directory.\nPlease select a sound file to be opened."),
+						       _("'%s' is a folder.\nPlease select a sound file to be opened."),
 						       tempfile);
 			g_signal_connect (G_OBJECT (mess), "response",
 					  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -660,6 +739,7 @@ store_filename (GtkFileSelection* selector, gpointer file_selector)
 	}
 	active_file = g_strdup (tempfile);
 	file_changed = FALSE;
+	save_set_sensitive (FALSE);
 	gtk_widget_destroy (GTK_WIDGET (file_selector));
 	
 	grecord_set_sensitive_file ();
@@ -720,7 +800,7 @@ save_filename (GtkFileSelection* selector, gpointer file_selector)
 			mess = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 						       GTK_MESSAGE_ERROR,
 						       GTK_BUTTONS_OK,
-						       _("'%s' is a directory.\nPlease enter another filename."),
+						       _("'%s' is a folder.\nPlease enter another filename."),
 						       new_file);
 			g_signal_connect (G_OBJECT (mess), "response",
 					  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -783,9 +863,81 @@ save_filename (GtkFileSelection* selector, gpointer file_selector)
 
 	set_window_title (active_file);
 	file_changed = FALSE;
+	save_set_sensitive (FALSE);
 	file_selector = NULL;
 }
 
+/* Yes I stole this from GEdit. */
+static GtkWidget *
+grec_button_new_with_stock_image (const char *text,
+				  const char *stock_id)
+{
+	GtkWidget *button;
+	GtkStockItem item;
+	GtkWidget *label;
+	GtkWidget *image;
+	GtkWidget *hbox;
+	GtkWidget *align;
+
+	button = gtk_button_new ();
+
+	if (GTK_BIN (button)->child) {
+		gtk_container_remove (GTK_CONTAINER (button),
+				      GTK_BIN (button)->child);
+	}
+
+	if (gtk_stock_lookup (stock_id, &item)) {
+		label = gtk_label_new_with_mnemonic (text);
+		gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
+
+		image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+		hbox = gtk_hbox_new (FALSE, 2);
+		align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+
+		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+		gtk_container_add (GTK_CONTAINER (button), align);
+		gtk_container_add (GTK_CONTAINER (align), hbox);
+		gtk_widget_show_all (align);
+
+		return button;
+	}
+
+	label = gtk_label_new_with_mnemonic (text);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
+	
+	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
+	gtk_widget_show (label);
+	gtk_container_add (GTK_CONTAINER (button), label);
+
+	return button;
+}
+
+static GtkWidget *
+grec_dialog_add_button (GtkDialog *dialog,
+			const char *text,
+			const char *stock_id,
+			int response_id)
+{
+	GtkWidget *button;
+
+	g_return_val_if_fail (GTK_IS_DIALOG (dialog), NULL);
+	g_return_val_if_fail (text != NULL, NULL);
+	g_return_val_if_fail (stock_id != NULL, NULL);
+
+	button = grec_button_new_with_stock_image (text, stock_id);
+	g_return_val_if_fail (button != NULL, NULL);
+
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+
+	gtk_widget_show (button);
+
+	gtk_dialog_add_action_widget (dialog, button, response_id);
+
+	return button;
+}
+
 gint
 save_dont_or_cancel (const char *quit_text)
 {
@@ -803,13 +955,16 @@ save_dont_or_cancel (const char *quit_text)
 	mess = gtk_message_dialog_new (grecord_widgets.grecord_window, 0,
 				       GTK_MESSAGE_WARNING,
 				       GTK_BUTTONS_NONE,
-				       _("<b>Save the changes to %s?</b>\nIf you don't save, these changes will be discarded."),
+				       _("<b>Do you want to save the changes you made to \"%s\"?</b>\n"
+					 "\nYour changes will be lost is you don't save them."),
 				       filename);
 	
-	gtk_dialog_add_buttons (GTK_DIALOG (mess),
-				_("Don't save"), DONTSAVE,
-				quit_text, CANCEL,
-				_("Save"), SAVE, NULL);
+	grec_dialog_add_button (GTK_DIALOG (mess),
+				_("Do_n't save"), GTK_STOCK_NO, DONTSAVE);
+	grec_dialog_add_button (GTK_DIALOG (mess),
+				quit_text, GTK_STOCK_CANCEL, CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (mess),
+			       GTK_STOCK_SAVE, SAVE);
 	gtk_dialog_set_default_response (GTK_DIALOG (mess), 0);
 
 	title = g_strdup_printf (_("Save %s?"), filename);
@@ -844,6 +999,8 @@ save_sound_file (const gchar* filename)
 
 		/* It's saved now */
 		default_file = FALSE;
+		save_set_sensitive (FALSE);
+		file_changed = FALSE;
 	}
 
 	/* No saving is needed, because the changes go directly to the active file; don't worry, */
@@ -914,10 +1071,15 @@ UpdateStatusbarRecord (gboolean begin)
 	}
 
 	/* Timeout */
-	if (counter >= 1000) {
+	if (counter >= record_timeout * 60) {
 		if (stop_on_timeout) {
 			on_stop_activate_cb (NULL, NULL);
-			return TRUE;
+
+			if (save_when_finished == TRUE) {
+				save_dialog ();
+			}
+
+			return FALSE;
 		}
 
 		counter /= 2;
@@ -944,8 +1106,7 @@ UpdateStatusbarRecord (gboolean begin)
 	
 	if (popup_warn_mess) {
 		struct stat fileinfo;
-		static gint maxfilesize = -1;
-		static gboolean show_message = TRUE;
+		gint maxfilesize = -1;
 		gchar* filename = g_build_filename (temp_dir, 
 						    temp_filename_record, NULL);
 		
@@ -973,7 +1134,7 @@ UpdateStatusbarRecord (gboolean begin)
 	
 	if (stop_record) {
 		struct stat fileinfo;
-		static gint maxfilesize = -1;
+		gint maxfilesize = -1;
 		gchar* filename = g_build_filename (temp_dir, 
 						    temp_filename_record, NULL);
 
@@ -990,14 +1151,19 @@ UpdateStatusbarRecord (gboolean begin)
 		}
 	}
 
-	/* Get the timeout value and convert it to seconds (if it isn't allready done) */
-	if (timeout == 0)
+	/* Get the timeout value and convert it to seconds
+	   (if it isn't already done) */
+	if (timeout == 0) {
 		timeout = record_timeout * 60;
+	}
 
-	counter += (int) 1000 / timeout;
+	counter++;
 
-	gtk_range_set_adjustment (GTK_RANGE (grecord_widgets.Statusbar), GTK_ADJUSTMENT (gtk_adjustment_new (counter, 0, 1000, 1, 1, 0)));
-/*  	gtk_range_slider_update (GTK_RANGE (grecord_widgets.Statusbar)); */
+	gtk_range_set_adjustment (GTK_RANGE (grecord_widgets.Statusbar),
+				  GTK_ADJUSTMENT (gtk_adjustment_new (counter,
+								      0,
+								      timeout,
+								      1, 1, 0)));
 
 	return TRUE;
 }
@@ -1013,14 +1179,14 @@ save_dialog (void)
 
 	if (!g_strcasecmp (active_file, temp_file)) {
 		gchar* home_dir = g_strdup (getenv ("HOME"));
-		gchar* default_file = g_build_filename (home_dir, 
-							_(temp_filename_play),
-							NULL);
+		gchar* d_file = g_build_filename (home_dir, 
+						  _(temp_filename_play),
+						  NULL);
 
-		gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), default_file);
+		gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), d_file);
 
 		g_free (home_dir);
-		g_free (default_file);
+		g_free (d_file);
 	}
 	else
 		gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), active_file);
@@ -1045,10 +1211,11 @@ is_file_default (void)
 	gchar* temp_string;
 	temp_string = g_build_filename (temp_dir, temp_filename_play, NULL);
 
-	if (!g_strcasecmp (temp_string, active_file))
+	if (!g_strcasecmp (temp_string, active_file)) {
 	        default_file = TRUE;
-	else
+	} else {
 		default_file = FALSE;
+	}
 
 	g_free (temp_string);
 }
@@ -1068,7 +1235,7 @@ void grecord_set_sensitive_file (void)
 
 void grecord_set_sensitive_nofile (void)
 {
-	gtk_widget_set_sensitive (GTK_WIDGET (grecord_widgets.Record_button), TRUE);
+	gtk_widget_set_sensitive (grecord_widgets.Record_button, able_to_record);
 	gtk_widget_set_sensitive (GTK_WIDGET (grecord_widgets.Play_button), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (grecord_widgets.Stop_button), FALSE);
 }
