@@ -49,7 +49,7 @@ static GnomeUIInfo arkiv1_menu_uiinfo[] =
 	GNOMEUIINFO_MENU_SAVE_AS_ITEM (on_saveas_activate_cb, NULL),
 	GNOMEUIINFO_SEPARATOR,
 	{
-		GNOME_APP_UI_ITEM, N_("Run mixer"),
+		GNOME_APP_UI_ITEM, N_("Run _Mixer"),
 		N_("Run GNOME Volume Control"),
 		on_runmixer_activate_cb, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_VOLUME,
@@ -106,7 +106,7 @@ static GnomeUIInfo edit_menu_uiinfo[] =
 {
 	/* GNOMEUIINFO_MENU_UNDO_ITEM (on_undo_activate_cb, NULL), */
 	{
-		GNOME_APP_UI_ITEM, N_("Undo all changes"),
+		GNOME_APP_UI_ITEM, N_("_Undo All"),
 		N_("Undo all changes made on the current sample"),
 		on_undoall_activate_cb, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_UNDO,
@@ -115,27 +115,7 @@ static GnomeUIInfo edit_menu_uiinfo[] =
 	/* GNOMEUIINFO_MENU_REDO_ITEM (on_redo_activate_cb, NULL), */
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_SUBTREE (N_("Effects"), effects_menu_uiinfo),
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo alternativ1_menu_uiinfo[] =
-{
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM (on_preferences_activate_cb, NULL),
-	GNOMEUIINFO_SEPARATOR,
-	{
-		GNOME_APP_UI_TOGGLEITEM, N_("Show time"),
-		N_("Show time"),
-		on_show_time_activate_cb, NULL, NULL,
-		GNOME_APP_PIXMAP_NONE, NULL,
-		0, 0, NULL,
-	},
-	{
-		GNOME_APP_UI_TOGGLEITEM, N_("Show soundinfo"),
-		N_("Show sound information"),
-		on_show_soundinfo_activate_cb, NULL, NULL,
-		GNOME_APP_PIXMAP_NONE, NULL,
-		0, 0, NULL,
-	},
 	GNOMEUIINFO_END
 };
 
@@ -150,13 +130,19 @@ GnomeUIInfo menubar1_uiinfo[] =
 {
 	GNOMEUIINFO_MENU_FILE_TREE (arkiv1_menu_uiinfo),
 	GNOMEUIINFO_MENU_EDIT_TREE (edit_menu_uiinfo),
-	GNOMEUIINFO_MENU_SETTINGS_TREE (alternativ1_menu_uiinfo),
 	GNOMEUIINFO_MENU_HELP_TREE (hj_lp1_menu_uiinfo),
 	GNOMEUIINFO_END
 };
 
 gpointer main_menu = menubar1_uiinfo;
 
+void
+save_set_sensitive (gboolean sensitivity)
+{
+	gtk_widget_set_sensitive (arkiv1_menu_uiinfo[2].widget, sensitivity);
+	gtk_widget_set_sensitive (arkiv1_menu_uiinfo[3].widget, sensitivity);
+}
+
 void
 set_window_title (const char *filename)
 {
@@ -172,14 +158,10 @@ set_window_title (const char *filename)
 GtkWidget*
 create_grecord_window (void)
 {
-	GtkWidget* vbox1;
+	GtkWidget* vbox;
 	GtkWidget* menubar;
 	GtkWidget* toolbar;
 	GtkWidget* tmp_toolbar_icon;
-	GtkWidget* vbox2;
-	GtkWidget* vbox3;
-	GtkWidget* frame1;
-	GtkWidget* vbox4;
 	GtkWidget* hbox1;
 	GtkWidget* grecord_appbar;
 	GtkWidget* mess;
@@ -223,15 +205,6 @@ create_grecord_window (void)
 	gnome_app_fill_menu (GTK_MENU_SHELL (menubar), menubar1_uiinfo,
 			     NULL, FALSE, 0);
 
-	if (show_time) {
-		GtkCheckMenuItem* menu_item = GTK_CHECK_MENU_ITEM (alternativ1_menu_uiinfo[2].widget);
-		menu_item->active = TRUE;
-	}
-	if (show_soundinfo) {
-		GtkCheckMenuItem* menu_item = GTK_CHECK_MENU_ITEM (alternativ1_menu_uiinfo[3].widget);
-		menu_item->active = TRUE;
-	}
-
 	toolbar = gtk_toolbar_new ();
 	gtk_widget_show (toolbar);
 
@@ -292,30 +265,13 @@ create_grecord_window (void)
 	}
 	gtk_widget_show (Record_button);
       
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox1);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 2);
+	gtk_widget_show (vbox);
 
-	vbox2 = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox2);
-	gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);
-	
-	vbox3 = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox3);
-	gtk_box_pack_start (GTK_BOX (vbox2), vbox3, TRUE, TRUE, 0);
-	
-	frame1 = gtk_frame_new (_("Info"));
-	gtk_widget_show (frame1);
-	gtk_box_pack_start (GTK_BOX (vbox3), frame1, TRUE, TRUE, 0);
-	gtk_widget_set_usize (frame1, -2, 70);
-	gtk_container_set_border_width (GTK_CONTAINER (frame1), 10);
-	
-	vbox4 = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox4);
-	gtk_container_add (GTK_CONTAINER (frame1), vbox4);
-	
 	hbox1 = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox1);
-	gtk_box_pack_start (GTK_BOX (vbox4), hbox1, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox1, FALSE, FALSE, 0);
 
 	Statusbar = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 1000, 1, 1, 0)));
 	gtk_widget_show (Statusbar);
@@ -333,42 +289,38 @@ create_grecord_window (void)
 	timesec_label = gtk_label_new ("00");
 	gtk_box_pack_start (GTK_BOX (hbox1), timesec_label, FALSE, TRUE, 4);
 
-	if (show_time) {
-		gtk_widget_show (timemin_label);
-		gtk_widget_show (timespace_label);
-		gtk_widget_show (timesec_label);
-	}
+	gtk_widget_show (timemin_label);
+	gtk_widget_show (timespace_label);
+	gtk_widget_show (timesec_label);
 
 	info_hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (info_hbox);
-	gtk_box_pack_start (GTK_BOX (vbox4), info_hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), info_hbox, FALSE, FALSE, 0);
 
 	temp_string = g_strconcat (_("Audio format: "), audioformat_string, NULL);
 	audio_format_label = gtk_label_new (temp_string);
 	g_free (temp_string);
-	gtk_box_pack_start (GTK_BOX (info_hbox), audio_format_label, TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (info_hbox), audio_format_label, TRUE, FALSE, 3);
 	gtk_label_set_justify (GTK_LABEL (audio_format_label), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (audio_format_label), TRUE);
 
 	temp_string = g_strconcat (_("Sample rate: "), samplerate, NULL);
 	sample_rate_label = gtk_label_new (temp_string);
 	g_free (temp_string);
-	gtk_box_pack_start (GTK_BOX (info_hbox), sample_rate_label, TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (info_hbox), sample_rate_label, TRUE, FALSE, 3);
 	gtk_label_set_justify (GTK_LABEL (sample_rate_label), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (sample_rate_label), TRUE);
 
 	temp_string = g_strconcat (_("Channels: "), channels_string, NULL);
 	nr_of_channels_label = gtk_label_new (temp_string);
 	g_free (temp_string);
-	gtk_box_pack_start (GTK_BOX (info_hbox), nr_of_channels_label, TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (info_hbox), nr_of_channels_label, TRUE, FALSE, 3);
 	gtk_label_set_justify (GTK_LABEL (nr_of_channels_label), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (nr_of_channels_label), TRUE);
 
-	if (show_soundinfo) {
-		gtk_widget_show (audio_format_label);
-		gtk_widget_show (sample_rate_label);
-		gtk_widget_show (nr_of_channels_label);
-	}
+	gtk_widget_show (audio_format_label);
+	gtk_widget_show (sample_rate_label);
+	gtk_widget_show (nr_of_channels_label);
 
 	grecord_appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_NEVER);
 	gtk_widget_show (grecord_appbar);	
@@ -392,9 +344,11 @@ create_grecord_window (void)
 	gnome_app_set_statusbar (GNOME_APP (grecord_window),  GTK_WIDGET (grecord_appbar));
 	gnome_app_set_menus (GNOME_APP (grecord_window), GTK_MENU_BAR (menubar));
 	gnome_app_set_toolbar (GNOME_APP (grecord_window), GTK_TOOLBAR (toolbar));
-	gnome_app_set_contents (GNOME_APP (grecord_window), GTK_WIDGET (vbox1));
+	gnome_app_set_contents (GNOME_APP (grecord_window), GTK_WIDGET (vbox));
 
 	gnome_app_install_menu_hints (GNOME_APP (grecord_window), menubar1_uiinfo);
+
+	save_set_sensitive (FALSE);
 	
 	/* Initiate mainwindow and set the topic */
 	is_file_default ();
@@ -467,6 +421,10 @@ create_about (void)
 		"Iain Holmes <iain@ximian.com>",
 		NULL
 	};
+	const char *documenters [] = {
+		NULL
+	};
+	const char *translator_credits = _("translator_credits");
 	GtkWidget* about;
 	
 	authors[0]=_(authors[0]);
@@ -475,7 +433,9 @@ create_about (void)
 				   "e" of Hyden by an "eacute" (U00E9) */
 				 _("Copyright (C)  2000 Andreas Hyden"),
 				 _("A simple soundrecorder and soundplayer for GNOME.\nDedicated to my cat, Malte."),
-				 authors, NULL, NULL,
+				 authors,
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 NULL);
 	
 	return about;
@@ -561,6 +521,14 @@ play_repeat_forever_changed (GtkToggleButton *tb,
 			       gtk_toggle_button_get_active (tb), NULL);
 }
 
+static void
+playxtimes_changed (GtkToggleButton *tb,
+		    gpointer data)
+{
+	gtk_widget_set_sensitive (propertywidgets.playxtimes_spinbutton_v,
+				  gtk_toggle_button_get_active (tb));
+}
+
 static void
 play_x_times_changed (GtkAdjustment *adj,
 		      gpointer data)
@@ -630,20 +598,27 @@ tmp_button_clicked (GtkButton *button,
 }
 
 static void
-audio_format_changed (GtkEntry *entry,
-		      gpointer data)
+bit8_toggled (GtkToggleButton *tb,
+	      gpointer data)
 {
-	gboolean format;
-	const char *text;
-
-	text = gtk_entry_get_text (entry);
-	if (strcmp (text, _("8bit PCM")) == 0) {
-		format = TRUE;
-	} else {
-		format = FALSE;
+	if (gtk_toggle_button_get_active (tb) == FALSE) {
+		return;
 	}
 
-	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/audio-format", format, NULL);
+	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/audio-format",
+			       TRUE, NULL);
+}
+
+static void
+bit16_toggled (GtkToggleButton *tb,
+	       gpointer data)
+{
+	if (gtk_toggle_button_get_active (tb) == FALSE) {
+		return;
+	}
+
+	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/audio-format",
+			       FALSE, NULL);
 }
 
 static void
@@ -655,36 +630,25 @@ sample_rate_changed (GtkEntry *entry,
 }
 
 static void
-channels_changed (GtkEntry *entry,
-		  gpointer data)
+mono_toggled (GtkToggleButton *tb,
+	      gpointer data)
 {
-	gboolean channels;
-	const char *text;
-
-	text = gtk_entry_get_text (entry);
-	if (strcmp (text, _("Mono")) == 0) {
-		channels = TRUE;
-	} else {
-		channels = FALSE;
+	if (gtk_toggle_button_get_active (tb) == FALSE) {
+		return;
 	}
 
-	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/channels", channels, NULL);
+	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/channels", TRUE, NULL);
 }
 
 static void
-show_time_changed (GtkToggleButton *tb,
-		   gpointer data)
+stereo_toggled (GtkToggleButton *tb,
+		gpointer data)
 {
-	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/show-time",
-			       gtk_toggle_button_get_active (tb), NULL);
-}
+	if (gtk_toggle_button_get_active (tb) == FALSE) {
+		return;
+	}
 
-static void
-show_soundinfo_changed (GtkToggleButton *tb,
-			gpointer data)
-{
-	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/show-sound-info",
-			       gtk_toggle_button_get_active (tb), NULL);
+	gconf_client_set_bool (client, "/apps/gnome-sound-recorder/channels", FALSE, NULL);
 }
 
 GtkWidget*
@@ -693,9 +657,9 @@ create_grecord_propertybox (void)
 	GtkWidget *grecord_propertybox;
 	GtkWidget *frame, *label;
 	GtkWidget *notebook;
-	GtkWidget *vbox, *inner_vbox;
+	GtkWidget *vbox, *inner_vbox, *hbox_vbox;
 	GtkWidget *hbox;
-	GtkWidget *button;
+	GtkWidget *button, *sep;
 	
 	GtkObject* spinbutton_adj;
 	GtkWidget* RecordTimeout_spinbutton;
@@ -707,22 +671,23 @@ create_grecord_propertybox (void)
 	GtkWidget* StopRecordSize_spinbutton;
 	GtkWidget* TempDir_fileentry;
 	GtkWidget* TempDir_combo_entry;
-	GtkWidget* Audioformat_combo;
-	GtkWidget* Audioformat_combo_entry;
+	GtkWidget *bit16_radiobutton;
+	GtkWidget *bit8_radiobutton;
 	GtkWidget* Samplerate_combo;
 	GtkWidget* Samplerate_combo_entry;
-	GtkWidget* NrChannel_combo;
-	GtkWidget* NrChannel_combo_entry;
 	GtkWidget* path_to_sox_fileentry;
 	GtkWidget* path_to_sox_combo_entry;
 	GtkWidget* mainwindow_gui_vbox;
 	GtkWidget* show_time_checkbutton;
 	GtkWidget* show_soundinfo_checkbutton;
-	GtkWidget* playrepeat_checkbox;
+	GtkWidget* playrepeat_radiobutton;
 	GtkWidget* playrepeatforever_radiobutton;
 	GtkWidget* playxtimes_radiobutton;
 	GtkWidget* playxtimes_spinbutton;
-
+	GtkWidget *mono_rb, *stereo_rb;
+	GtkWidget* path_to_sox_gnomeentry;
+	GtkWidget* TempDir_gnomeentry;
+	
 	GList *items = NULL;
 
 	if (client == NULL) {
@@ -734,6 +699,7 @@ create_grecord_propertybox (void)
 							   GTK_DIALOG_DESTROY_WITH_PARENT,
 							   GTK_STOCK_CLOSE,
 							   GTK_RESPONSE_CLOSE, NULL);
+	gtk_window_set_title (GTK_WINDOW (grecord_propertybox), _("Sound Recorder Preferences"));
 	g_signal_connect (G_OBJECT (grecord_propertybox), "response",
 			  G_CALLBACK (response_cb), NULL);
 
@@ -763,7 +729,7 @@ create_grecord_propertybox (void)
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, TRUE, TRUE, 0);
 	
-	label = gtk_label_new (_("Recording timeout: "));
+	label = gtk_label_new_with_mnemonic (_("_Recording timeout: "));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_misc_set_padding (GTK_MISC (label), 5, 0);
@@ -773,16 +739,20 @@ create_grecord_propertybox (void)
 			  G_CALLBACK (record_timeout_changed), NULL);
 	
 	RecordTimeout_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adj), 1, 0);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), RecordTimeout_spinbutton);
 	gtk_widget_show (RecordTimeout_spinbutton);
-	gtk_container_add (GTK_CONTAINER (hbox), RecordTimeout_spinbutton);
+	gtk_box_pack_start (GTK_BOX (hbox), RecordTimeout_spinbutton, FALSE, FALSE, 0);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (RecordTimeout_spinbutton), TRUE);
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, RecordTimeout_spinbutton, ATK_RELATION_LABELLED_BY);
 	
 	label = gtk_label_new (_("minutes"));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_misc_set_padding (GTK_MISC (label), 5, 0);
 	
-	StopRecordOnTimeout_checkbox = gtk_check_button_new_with_label (_("Stop recording on timeout"));
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, RecordTimeout_spinbutton, ATK_RELATION_LABELLED_BY);
+	
+	StopRecordOnTimeout_checkbox = gtk_check_button_new_with_mnemonic (_("_Stop recording on timeout"));
 
 	g_signal_connect (G_OBJECT (StopRecordOnTimeout_checkbox), "toggled",
 			  G_CALLBACK (stop_on_timeout_changed), NULL);
@@ -790,7 +760,7 @@ create_grecord_propertybox (void)
 	gtk_box_pack_start (GTK_BOX (inner_vbox), StopRecordOnTimeout_checkbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (StopRecordOnTimeout_checkbox), 3);
 	
-	PopupSaveOnTimeout_checkbox = gtk_check_button_new_with_label (_("Popup save dialog when recording is finished"));
+	PopupSaveOnTimeout_checkbox = gtk_check_button_new_with_mnemonic (_("_Open save dialog when recording is finished"));
 	g_signal_connect (G_OBJECT (PopupSaveOnTimeout_checkbox), "toggled",
 			  G_CALLBACK (save_when_finished_changed), NULL);
 	gtk_widget_show (PopupSaveOnTimeout_checkbox);
@@ -806,7 +776,7 @@ create_grecord_propertybox (void)
 	gtk_widget_show (inner_vbox);
 	gtk_container_add (GTK_CONTAINER (frame), inner_vbox);
 	
-	PopupWarnMessSize_checkbox = gtk_check_button_new_with_label (_("Popup warning message if size (Mb) of sample becomes bigger than:"));
+	PopupWarnMessSize_checkbox = gtk_check_button_new_with_mnemonic (_("Show warning _message if size (Mb) of sample becomes bigger than:"));
 	g_signal_connect (G_OBJECT (PopupWarnMessSize_checkbox), "toggled",
 			  G_CALLBACK (popup_warning_changed), NULL);
 			  
@@ -824,7 +794,7 @@ create_grecord_propertybox (void)
 	add_paired_relations (PopupWarnMessSize_checkbox, ATK_RELATION_CONTROLLER_FOR,
 			      WarningSize_spinbutton, ATK_RELATION_CONTROLLED_BY);
 	
-	StopRecordSize_checkbox = gtk_check_button_new_with_label (_("Stop recording if size (Mb) of sample becomes bigger than:"));
+	StopRecordSize_checkbox = gtk_check_button_new_with_mnemonic (_("Sto_p recording if size (Mb) of sample becomes bigger than:"));
 	g_signal_connect (G_OBJECT (StopRecordSize_checkbox), "toggled",
 			  G_CALLBACK (stop_record_changed), NULL);
 	
@@ -860,29 +830,37 @@ create_grecord_propertybox (void)
 	gtk_widget_show (inner_vbox);
 	gtk_container_add (GTK_CONTAINER (frame), inner_vbox);
 
-	playrepeat_checkbox = gtk_check_button_new_with_label (_("Repeat the sound"));
+#if 0
+	playrepeat_checkbox = gtk_check_button_new_with_mnemonic (_("_Repeat the sound"));
 	g_signal_connect (G_OBJECT (playrepeat_checkbox), "toggled",
 			  G_CALLBACK (play_repeat_changed), NULL);
 	gtk_widget_show (playrepeat_checkbox);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), playrepeat_checkbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (playrepeat_checkbox), 3);
-
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_widget_show (hbox);
-	gtk_container_add (GTK_CONTAINER (inner_vbox), hbox);
-
-	playrepeatforever_radiobutton = gtk_radio_button_new_with_label (NULL, _("Forever"));
+#endif
+	playrepeat_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Play the sound _once only."));
+	gtk_box_pack_start (GTK_BOX (inner_vbox), playrepeat_radiobutton, FALSE, FALSE, 0);
+	gtk_widget_show (playrepeat_radiobutton);
+	g_signal_connect (G_OBJECT (playrepeat_radiobutton), "toggled",
+			  G_CALLBACK (play_repeat_changed), NULL);
+	
+	playrepeatforever_radiobutton = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (playrepeat_radiobutton), _("Repeat _forever"));
 	g_signal_connect (G_OBJECT (playrepeatforever_radiobutton), "toggled",
 			  G_CALLBACK (play_repeat_forever_changed), NULL);
 	
 	gtk_widget_show (playrepeatforever_radiobutton);
-	gtk_box_pack_start (GTK_BOX (hbox), playrepeatforever_radiobutton, FALSE, FALSE, 20);
-	gtk_container_set_border_width (GTK_CONTAINER (playrepeatforever_radiobutton), 3);
+	gtk_box_pack_start (GTK_BOX (inner_vbox), playrepeatforever_radiobutton, FALSE, FALSE, 0);
 
-	playxtimes_radiobutton = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (playrepeatforever_radiobutton), _("Nr of times:"));
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (hbox);
+	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, FALSE, FALSE, 0);
+
+	playxtimes_radiobutton = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (playrepeatforever_radiobutton), _("_Number of times:"));
 	gtk_widget_show (playxtimes_radiobutton);
+	g_signal_connect (G_OBJECT (playxtimes_radiobutton), "toggled",
+			  G_CALLBACK (playxtimes_changed), NULL);
+	
 	gtk_box_pack_start (GTK_BOX (hbox), playxtimes_radiobutton, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (playxtimes_radiobutton), 3);
 
 	spinbutton_adj = gtk_adjustment_new (1, 1, 1000, 1, 10, 10);
 	g_signal_connect (G_OBJECT (spinbutton_adj), "value-changed",
@@ -893,8 +871,6 @@ create_grecord_propertybox (void)
 	gtk_box_pack_start (GTK_BOX (hbox), playxtimes_spinbutton, TRUE, TRUE, 0);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (playxtimes_spinbutton), TRUE);
 	
-	add_paired_relations (playrepeat_checkbox, ATK_RELATION_CONTROLLER_FOR, playrepeatforever_radiobutton, ATK_RELATION_CONTROLLED_BY);
-	add_paired_relations (playrepeat_checkbox, ATK_RELATION_CONTROLLER_FOR, playxtimes_radiobutton, ATK_RELATION_CONTROLLED_BY);
 	add_paired_relations (playxtimes_radiobutton, ATK_RELATION_LABEL_FOR, playxtimes_spinbutton, ATK_RELATION_LABELLED_BY);
 
 	vbox = gtk_vbox_new (FALSE, 0);
@@ -918,7 +894,7 @@ create_grecord_propertybox (void)
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, TRUE, TRUE, 0);
 
-	label = gtk_label_new (_("Path to sox:"));
+	label = gtk_label_new_with_mnemonic (_("_Path to sox:"));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
@@ -927,9 +903,12 @@ create_grecord_propertybox (void)
 	gtk_box_pack_start (GTK_BOX (hbox), path_to_sox_fileentry, TRUE, TRUE, 0);
 
 	path_to_sox_combo_entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (path_to_sox_fileentry));
-	gtk_widget_show (path_to_sox_combo_entry);
-
-	button = gtk_button_new_with_label (_("Apply"));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), path_to_sox_combo_entry);
+	
+	path_to_sox_gnomeentry = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (path_to_sox_fileentry));
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, path_to_sox_gnomeentry, ATK_RELATION_LABELLED_BY);
+	
+	button = gtk_button_new_with_mnemonic (_("_Apply"));
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
@@ -938,7 +917,7 @@ create_grecord_propertybox (void)
 	g_signal_connect (G_OBJECT (button), "clicked",
 			  G_CALLBACK (sox_button_clicked), path_to_sox_combo_entry);
 
-	frame = gtk_frame_new (_("Directories"));
+	frame = gtk_frame_new (_("Folders"));
 	gtk_widget_show (frame);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 3);
@@ -951,7 +930,7 @@ create_grecord_propertybox (void)
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, TRUE, TRUE, 0);
 	
-	label = gtk_label_new (_("Temporary directory:"));
+	label = gtk_label_new_with_mnemonic (_("_Temporary folder:"));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
@@ -960,8 +939,11 @@ create_grecord_propertybox (void)
 	gtk_box_pack_start (GTK_BOX (hbox), TempDir_fileentry, TRUE, TRUE, 0);
 	
 	TempDir_combo_entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (TempDir_fileentry));
-	gtk_widget_show (TempDir_combo_entry);
-
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), TempDir_combo_entry);
+	
+	TempDir_gnomeentry = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (TempDir_fileentry));
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, TempDir_gnomeentry, ATK_RELATION_LABELLED_BY);
+	
 	button = gtk_button_new_with_label (_("Apply"));
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
@@ -987,42 +969,50 @@ create_grecord_propertybox (void)
 	inner_vbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (inner_vbox);
 	gtk_container_add (GTK_CONTAINER (frame), inner_vbox);
+
+	label = gtk_label_new (_("Note: These options only take effect whenever a new sound sample\n"
+				 "is created. They do not operate on an existing sample."));
+	gtk_box_pack_start (GTK_BOX (inner_vbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+
+	sep = gtk_hseparator_new ();
+	gtk_box_pack_start (GTK_BOX (inner_vbox), sep, FALSE, FALSE, 2);
+	gtk_widget_show (sep);
 	
 	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, TRUE, TRUE, 0);
-
+	
 	label = gtk_label_new (_("Audio format:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0);
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-	/* Use radiobutton, not combo. Combo's suck :) */
-	Audioformat_combo = gtk_combo_new ();
-	gtk_widget_show (Audioformat_combo);
-	gtk_box_pack_start (GTK_BOX (hbox), Audioformat_combo, FALSE, TRUE, 0);
-	items = g_list_append (NULL, _("8bit PCM"));
-	items = g_list_append (items, _("16bit PCM"));
-	gtk_combo_set_popdown_strings (GTK_COMBO (Audioformat_combo), items);
-	g_list_free (items);
-	gtk_container_set_border_width (GTK_CONTAINER (Audioformat_combo), 7);
+	hbox_vbox = gtk_vbox_new (FALSE, 0);
+	gtk_widget_show (hbox_vbox);
+	gtk_box_pack_start (GTK_BOX (hbox), hbox_vbox, TRUE, TRUE, 0);
+
+	bit8_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("8 _bit PCM"));
+	g_signal_connect (G_OBJECT (bit8_radiobutton), "toggled",
+			  G_CALLBACK (bit8_toggled), NULL);
+	gtk_box_pack_start (GTK_BOX (hbox_vbox), bit8_radiobutton, FALSE, FALSE, 0);
+	gtk_widget_show (bit8_radiobutton);
 	
-	Audioformat_combo_entry = GTK_COMBO (Audioformat_combo)->entry;
-	gtk_widget_show (Audioformat_combo_entry);
-	gtk_entry_set_editable (GTK_ENTRY (Audioformat_combo_entry), FALSE);
-	g_signal_connect (G_OBJECT (Audioformat_combo_entry), "changed",
-			  G_CALLBACK (audio_format_changed), NULL);
-	if (audioformat)
-		gtk_entry_set_text (GTK_ENTRY (Audioformat_combo_entry), _("8bit PCM"));
-	else
-		gtk_entry_set_text (GTK_ENTRY (Audioformat_combo_entry), _("16bit PCM"));
-	
-	add_paired_relations (label, ATK_RELATION_LABEL_FOR, Audioformat_combo, ATK_RELATION_LABELLED_BY);
+	bit16_radiobutton = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (bit8_radiobutton), _("16 b_it PCM"));
+	g_signal_connect (G_OBJECT (bit16_radiobutton), "toggled",
+			  G_CALLBACK (bit16_toggled), NULL);
+	gtk_box_pack_start (GTK_BOX (hbox_vbox), bit16_radiobutton, FALSE, FALSE, 0);
+	gtk_widget_show (bit16_radiobutton);
 	
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, TRUE, TRUE, 0);
 	
-	label = gtk_label_new (_("Sample rate:"));
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, bit8_radiobutton, ATK_RELATION_LABELLED_BY);
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, bit16_radiobutton, ATK_RELATION_LABELLED_BY);
+	
+	/* If only combos didn't suck! */
+	label = gtk_label_new_with_mnemonic (_("S_ample rate:"));
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	
@@ -1046,16 +1036,44 @@ create_grecord_propertybox (void)
 	gtk_widget_show (Samplerate_combo_entry);
 	gtk_entry_set_text (GTK_ENTRY (Samplerate_combo_entry), _(samplerate));
 	
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), Samplerate_combo_entry);
 	add_paired_relations (label, ATK_RELATION_LABEL_FOR, Samplerate_combo, ATK_RELATION_LABELLED_BY);
 	
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), hbox, TRUE, TRUE, 0);
 	
-	label = gtk_label_new (_("Mono/Stereo"));
+	label = gtk_label_new (_("Mono or Stereo:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0);
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
+	hbox_vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), hbox_vbox, TRUE, TRUE, 0);
+	gtk_widget_show (hbox_vbox);
+
+	mono_rb = gtk_radio_button_new_with_mnemonic (NULL, _("_Mono"));
+	g_signal_connect (G_OBJECT (mono_rb), "toggled",
+			  G_CALLBACK (mono_toggled), NULL);
+	gtk_box_pack_start (GTK_BOX (hbox_vbox), mono_rb, FALSE, FALSE, 0);
+	gtk_widget_show (mono_rb);
+
+	stereo_rb = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (mono_rb), _("_Stereo"));
+	g_signal_connect (G_OBJECT (stereo_rb), "toggled",
+			  G_CALLBACK (stereo_toggled), NULL);
+	gtk_box_pack_start (GTK_BOX (hbox_vbox), stereo_rb, FALSE, FALSE, 0);
+	gtk_widget_show (stereo_rb);
+	
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, mono_rb, ATK_RELATION_LABELLED_BY);
+	add_paired_relations (label, ATK_RELATION_LABEL_FOR, stereo_rb, ATK_RELATION_LABELLED_BY);
+	
+	if (channels) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mono_rb), TRUE);
+	} else {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (stereo_rb), TRUE);
+	}
+
+#if 0
 	/* Radiobuttons, not combo */
 	NrChannel_combo = gtk_combo_new ();
 	gtk_widget_show (NrChannel_combo);
@@ -1071,44 +1089,8 @@ create_grecord_propertybox (void)
 	gtk_entry_set_editable (GTK_ENTRY (NrChannel_combo_entry), FALSE);
 	g_signal_connect (G_OBJECT (NrChannel_combo_entry), "changed",
 			  G_CALLBACK (channels_changed), NULL);
-	if (channels)
-		gtk_entry_set_text (GTK_ENTRY (NrChannel_combo_entry), _("Mono"));
-	else
-		gtk_entry_set_text (GTK_ENTRY (NrChannel_combo_entry), _("Stereo"));
-	
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox);
+#endif	
 
-	label = gtk_label_new (_("User interface"));
-	gtk_widget_show (label);
-	
-	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
-
-	frame = gtk_frame_new (_("Main window"));
-	gtk_widget_show (frame);
-	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (frame), 3);
-
-	inner_vbox = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (inner_vbox);
-	gtk_container_add (GTK_CONTAINER (frame), inner_vbox);
-
-	show_time_checkbutton = gtk_check_button_new_with_label (_("Show time"));
-	g_signal_connect (G_OBJECT (show_time_checkbutton), "toggled",
-			  G_CALLBACK (show_time_changed), NULL);
-	gtk_widget_show (show_time_checkbutton);
-	gtk_box_pack_start (GTK_BOX (inner_vbox), show_time_checkbutton, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (show_time_checkbutton), 3);
-
-	show_soundinfo_checkbutton = gtk_check_button_new_with_label (_("Show sound information"));
-	g_signal_connect (G_OBJECT (show_soundinfo_checkbutton), "toggled",
-			  G_CALLBACK (show_soundinfo_changed), NULL);
-	
-	gtk_widget_show (show_soundinfo_checkbutton);
-	gtk_box_pack_start (GTK_BOX (inner_vbox), show_soundinfo_checkbutton, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (show_soundinfo_checkbutton), 3);
-
-	/* Define structure propertywidgets ---------------------------------------------------- */
 	propertywidgets.RecordTimeout_spinbutton_v = RecordTimeout_spinbutton;
 	propertywidgets.StopRecordOnTimeout_checkbox_v = StopRecordOnTimeout_checkbox;
 	propertywidgets.PopupSaveOnTimeout_checkbox_v = PopupSaveOnTimeout_checkbox;
@@ -1117,7 +1099,7 @@ create_grecord_propertybox (void)
 	propertywidgets.StopRecordSize_checkbox_v = StopRecordSize_checkbox;
 	propertywidgets.StopRecordSize_spinbutton_v = StopRecordSize_spinbutton;
 
-	propertywidgets.playrepeat_checkbox_v = playrepeat_checkbox;
+	propertywidgets.playrepeat_checkbox_v = playrepeat_radiobutton;
 	propertywidgets.playrepeatforever_radiobutton_v = playrepeatforever_radiobutton;
 	propertywidgets.playxtimes_radiobutton_v = playxtimes_radiobutton;
 	propertywidgets.playxtimes_spinbutton_v = playxtimes_spinbutton;
@@ -1125,14 +1107,8 @@ create_grecord_propertybox (void)
 	propertywidgets.Sox_fileentry_v = path_to_sox_fileentry;
 	propertywidgets.TempDir_fileentry_v = TempDir_fileentry;
 
-	propertywidgets.Audioformat_combo_entry_v = Audioformat_combo_entry;
 	propertywidgets.Samplerate_combo_entry_v = Samplerate_combo_entry;
-	propertywidgets.NrChannel_combo_entry_v = NrChannel_combo_entry;
 
-	propertywidgets.show_time_checkbutton_v = show_time_checkbutton;
-	propertywidgets.show_soundinfo_checkbutton_v = show_soundinfo_checkbutton;
-
-	/* Set default vaules from config file ------------------------------------------------- */
 	gtk_entry_set_text (GTK_ENTRY (path_to_sox_combo_entry), sox_command);
 	gtk_entry_set_text (GTK_ENTRY (TempDir_combo_entry), temp_dir);	
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (RecordTimeout_spinbutton), record_timeout);
@@ -1144,41 +1120,30 @@ create_grecord_propertybox (void)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (PopupSaveOnTimeout_checkbox), save_when_finished);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (PopupWarnMessSize_checkbox), popup_warn_mess);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (StopRecordSize_checkbox), stop_record);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (show_time_checkbutton), show_time);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (show_soundinfo_checkbutton), show_soundinfo);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (playrepeat_checkbox), playrepeat);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (playrepeat_radiobutton), playrepeat);
 
-	if (playrepeatforever)
+	if (playrepeat) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (playrepeat_radiobutton), TRUE);
+	} else if (playrepeatforever) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (playrepeatforever_radiobutton), TRUE);
-	else
+	} else {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (playxtimes_radiobutton), TRUE);
-
+	}
+	
 	if (!popup_warn_mess)
 		gtk_widget_set_sensitive (WarningSize_spinbutton, FALSE);
 	if (!stop_record)
 		gtk_widget_set_sensitive (StopRecordSize_spinbutton, FALSE);
 
-	if (!playrepeat) {
-		gtk_widget_set_sensitive (playrepeatforever_radiobutton, FALSE);
-		gtk_widget_set_sensitive (playxtimes_radiobutton, FALSE);
-		gtk_widget_set_sensitive (playxtimes_spinbutton, FALSE);
-	}
-
-	if (playrepeatforever)
+	if (playrepeatforever || playrepeat)
 		gtk_widget_set_sensitive (playxtimes_spinbutton, FALSE);
 
-	/* Callbacks ---------------------------------------------------------------------------- */
 	g_signal_connect (PopupWarnMessSize_checkbox, "clicked", 
 			  G_CALLBACK (on_checkbox_clicked_activate_cb), 
 			  WarningSize_spinbutton);
 	g_signal_connect (StopRecordSize_checkbox, "clicked", 
 			  G_CALLBACK (on_checkbox_clicked_activate_cb), 
 			  StopRecordSize_spinbutton);
-	g_signal_connect (playrepeat_checkbox, "clicked", 
-			  G_CALLBACK (on_repeat_activate_cb), NULL);
-	g_signal_connect (playxtimes_radiobutton, "toggled", 
-			  G_CALLBACK (on_checkbox_clicked_activate_cb), 
-			  playxtimes_spinbutton);
 
 	return grecord_propertybox;
 }
